@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.9
+;; Version: 1.10
 ;; Package-Requires: ((emacs "29.1") (org "9.6") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
@@ -416,7 +416,7 @@ the font.")
        beg end 'face
        (if-let ((face (or (cdr (assq prio org-modern-priority-faces))
                           (cdr (assq t org-modern-priority-faces)))))
-           `(:inherit (,face org-modern-label))
+           `(,face org-modern-label)
          'org-modern-priority)))))
 
 (defun org-modern--progress ()
@@ -468,7 +468,7 @@ the font.")
              (if-let ((faces org-modern-tag-faces)
                       (face (or (cdr (assoc (buffer-substring-no-properties colon-end cbeg) faces))
                                 (cdr (assq t faces)))))
-                 `(:inherit (,face org-modern-tag))
+                 `(,face org-modern-tag)
                'org-modern-tag)))
           (add-text-properties cbeg cend colon-props)
           (setq colon-beg cbeg colon-end cend))))))
@@ -485,7 +485,7 @@ the font.")
      beg end 'face
      (if-let ((face (or (cdr (assoc todo org-modern-todo-faces))
                         (cdr (assq t org-modern-todo-faces)))))
-         `(:inherit (,face org-modern-label))
+         `(,face org-modern-label)
        (if (string-match-p org-not-done-regexp todo)
            'org-modern-todo 'org-modern-done)))))
 
@@ -920,7 +920,7 @@ whole buffer; otherwise, for the line at point."
           (while (< (point) (point-max))
             (when-let ((org-not-done-regexp (get-text-property (point) 'org-not-done-regexp))
                        (re (get-text-property (point) 'org-todo-regexp))
-                       (re (concat " " re " "))
+                       (re (concat "[: ]" re " "))
                        ((re-search-forward re (pos-eol) 'noerror)))
               (org-modern--todo))
             (goto-char (min (1+ (pos-eol)) (point-max)))))
